@@ -1,9 +1,8 @@
-use 5.008;
+package JSON::Path;
+$JSON::Path::VERSION = '1.0.0';
 use strict;
 use warnings;
 
-package JSON::Path;
-$JSON::Path::VERSION = '0.51';
 # VERSION
 
 use Exporter::Shiny qw/ jpath jpath1 jpath_map /;
@@ -135,7 +134,7 @@ JSON::Path
 
 =head1 VERSION
 
-version 0.51
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -385,6 +384,8 @@ Heiko Jansen E<lt>hjansen@cpan.orgE<gt>.
 
 Mitsuhiro Nakamura E<lt>m.nacamura@gmail.comE<gt>
 
+David Escribano García https://github.com/DavidEGx
+
 =head1 COPYRIGHT AND LICENCE
 
 Copyright 2007 Stefan Goessner.
