@@ -1,9 +1,8 @@
+package JSON::Path::Constants;
+$JSON::Path::Constants::VERSION = '1.0.0';
 use strict;
 use warnings;
-use 5.008;
 
-package JSON::Path::Constants;
-$JSON::Path::Constants::VERSION = '0.51';
 # ABSTRACT: Constants used in the JSON::Path distribution
 
 # VERSION
@@ -87,7 +86,7 @@ JSON::Path::Constants - Constants used in the JSON::Path distribution
 
 =head1 VERSION
 
-version 0.51
+version 1.0.0
 
 =head1 AUTHOR
 
