@@ -1,8 +1,7 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '0.51';
+$JSON::Path::Evaluator::VERSION = '1.0.0';
 use strict;
 use warnings;
-use 5.008;
 
 # ABSTRACT: A module that recursively evaluates JSONPath expressions with native support for Javascript-style filters
 
@@ -123,8 +122,8 @@ sub evaluate {
 sub _reftable_walker {
     my ( $self, $json_object, $base_path ) = @_;
 
-    $base_path   = defined $base_path   ? $base_path   : '$';
-    $json_object = defined $json_object ? $json_object : $self->root;
+    $base_path   //= '$';
+    $json_object //= $self->root;
 
     my @entries = ( refaddr $json_object => $base_path );
 
@@ -158,7 +157,7 @@ sub _evaluate {    # This assumes that the token stream is syntactically valid
 
     return unless ref $obj;
 
-    $token_stream = defined $token_stream ? $token_stream : [];
+    $token_stream //= [];
 
     while ( defined( my $token = shift @{$token_stream} ) ) {
         next if $token eq $TOKEN_CURRENT;
@@ -486,24 +485,25 @@ sub _process_pseudo_js {
         foreach my $expression (@expressions_and) {
 
             my ( $lhs, $operator, $rhs ) = _parse_psuedojs_expression($expression);
+            $lhs =~ s/^\s+|\s+$//g;
 
             my (@token_stream) = tokenize($lhs);
 
-            my @lhs;
             if ( _hashlike($object) ) {
-                @lhs = map { $self->_evaluate( $_, [@token_stream] ) } values %{$object};
-            }
-            elsif ( _arraylike($object) ) {
-                for my $value ( @{$object} ) {
-                    my ($got) = $self->_evaluate( $value, [@token_stream] );
-                    push @lhs, $got;
+                while (my ($k, $v) = each(%$object)) {
+                  my @got = $self->_evaluate( $v, [@token_stream] );
+                  foreach my $got (@got) {
+                      $matching_and{$k}++ if _compare( $operator, $got, $rhs );
+                  }
                 }
             }
-
-            # get indexes that pass compare()
-            for ( 0 .. $#lhs ) {
-                my $val = $lhs[$_];
-                $matching_and{$_}++ if _compare( $operator, $val, $rhs );
+            elsif ( _arraylike($object) ) {
+                my $idx = 0;
+                for my $value ( @{$object} ) {
+                    my ($got) = $self->_evaluate( $value, [@token_stream] );
+                    $matching_and{$idx}++ if _compare( $operator, $got, $rhs );
+                    $idx++;
+                }
             }
         }
         while (my ($idx, $val) = each(%matching_and)) {
@@ -654,7 +654,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 0.51
+version 1.0.0
 
 =head1 SYNOPSIS
 
