@@ -1,8 +1,7 @@
 package JSON::Path::Tokenizer;
-$JSON::Path::Tokenizer::VERSION = '0.51';
+$JSON::Path::Tokenizer::VERSION = '1.0.0';
 use strict;
 use warnings;
-use 5.008;
 
 use Carp;
 use Readonly;
@@ -125,7 +124,7 @@ JSON::Path::Tokenizer - Helper class for JSON::Path::Evaluator. Do not call dire
 
 =head1 VERSION
 
-version 0.51
+version 1.0.0
 
 =head1 AUTHOR
 
